@@ -4,7 +4,7 @@ from djconnectwise import sync, api
 from djconnectwise.utils import DjconnectwiseSettings
 
 from django.core.management.base import BaseCommand, CommandError
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 OPTION_NAME = 'connectwise_object'
 
